typedef struct
{
    int x;
    int y;
    int z;
} point_t;

int main()
{
    point_t *point = 0;
    int z;
    z = point->z;
    return z;
}
